@@ -11,7 +11,7 @@ html_extra_path = [os.path.join(html_theme_path[0], html_theme, "static", "img")
 templates_path = [os.path.join(html_theme_path[0], html_theme, "templates")]
 html_favicon = os.path.join(html_static_path[0], "img", "favicon-32.ico")
 svg_icon = os.path.join(html_static_path[0], "img", "sunpy_icon.svg")
-
+png_icon = os.path.join(html_static_path[0], "img", "sunpy_icon_128x128.png")
 on_rtd = os.environ.get("READTHEDOCS", False) == "True"
 
 if on_rtd:
@@ -76,30 +76,15 @@ html_theme_options = {
                 ("Community Roles", page_url("project/roles.html"), 1),
                 ("Affiliated Packages", page_url("project/affiliated.html"), 1),
                 ("Emeritus role holders", page_url("project/former.html"), 1),
+                ("Meetings", page_url("project/meetings.html"), 1),
             ],
             1,
         ),
     ],
     # Only really setup to look nice with 3 values.
     "footer_links": [
-        ("Github", "https://github.com/sunpy/sunpy", 1),
+        ("GitHub", "https://github.com/sunpy/sunpy", 1),
         ("Twitter", "https://twitter.com/SunPyProject", 1),
-        ("Matrix", "https://app.element.io/#/room/#sunpy:openastronomy.org", 1),
+        ("Chat (Matrix)", "https://openastronomy.element.io/#/room/#sunpy:openastronomy.org", 1),
     ],
 }
-
-
-def fix_circleci(app):
-    # Circle CI does weird things with redirections, which seem to break the
-    # import statements in the css files in the bootstrap theme. By doing this
-    # here we include these css files which are normally imported directly in
-    # the html which means they redirect properly. We only need to do this on
-    # circleci.
-    print(f"Checking for circleci: {os.environ.get('CIRCLECI')}")
-    if os.environ.get("CIRCLECI"):
-        app.add_css_file("basic.css")
-        app.add_css_file("bootswatch-3.3.7/flatly/bootstrap.min.css")
-
-
-def setup(app):
-    fix_circleci(app)
